pub struct RuleEngine { /* private fields */ }Expand description
Integrated rule engine combining all reasoning modes
Implementations
Sourceimpl RuleEngine
impl RuleEngine
pub fn new() -> Self
Sourcepub fn forward_chain(&mut self, facts: &[RuleAtom]) -> Result<Vec<RuleAtom>>
pub fn forward_chain(&mut self, facts: &[RuleAtom]) -> Result<Vec<RuleAtom>>
Perform forward chaining inference
Sourcepub fn backward_chain(&mut self, goal: &RuleAtom) -> Result<bool>
pub fn backward_chain(&mut self, goal: &RuleAtom) -> Result<bool>
Perform backward chaining to prove a goal
Sourcepub fn rete_forward_chain(
&mut self,
facts: Vec<RuleAtom>,
) -> Result<Vec<RuleAtom>>
pub fn rete_forward_chain( &mut self, facts: Vec<RuleAtom>, ) -> Result<Vec<RuleAtom>>
Perform RETE-based forward chaining
Sourcepub fn set_backward_chain_max_depth(&mut self, max_depth: usize)
pub fn set_backward_chain_max_depth(&mut self, max_depth: usize)
Set maximum proof depth for backward chaining
This limits the recursion depth to prevent stack overflow. Lower values (e.g., 20-30) are safer for large datasets. Default is 100.
Sourcepub fn set_cache(&mut self, cache: Option<RuleCache>)
pub fn set_cache(&mut self, cache: Option<RuleCache>)
Set cache for the rule engine
Enables or disables caching by setting the cache instance.
Pass Some(cache) to enable caching with a specific cache configuration,
or None to disable caching.
Sourcepub fn get_cache(&self) -> Option<&RuleCache>
pub fn get_cache(&self) -> Option<&RuleCache>
Get a reference to the cache
Returns a reference to the cache if enabled. The cache is wrapped in Option to allow disabling caching.
Sourcepub fn get_cache_mut(&mut self) -> Option<&mut RuleCache>
pub fn get_cache_mut(&mut self) -> Option<&mut RuleCache>
Get mutable reference to the cache
Returns a mutable reference to the cache if enabled. Useful for clearing cache, updating statistics, etc.
Sourcepub fn enable_cache(&mut self)
pub fn enable_cache(&mut self)
Enable caching with default settings
Creates a new cache with default configuration and enables it.
Sourcepub fn disable_cache(&mut self)
pub fn disable_cache(&mut self)
Disable caching
Removes the cache and disables caching functionality.
Sourcepub fn is_cache_enabled(&self) -> bool
pub fn is_cache_enabled(&self) -> bool
Check if caching is enabled
Sourcepub fn clear_cache(&mut self)
pub fn clear_cache(&mut self)
Clear the cache if enabled
Clears all cached rule results, derivations, unifications, and patterns.
Sourcepub fn get_cache_statistics(&self) -> Option<CachingStatistics>
pub fn get_cache_statistics(&self) -> Option<CachingStatistics>
Get cache statistics if caching is enabled
Returns combined statistics for all cache types (rule results, derivations, etc.)
Sourcepub fn warm_cache(&self, common_facts: &[RuleAtom])
pub fn warm_cache(&self, common_facts: &[RuleAtom])
Warm up the cache with current rules and common facts
Pre-populates the cache with patterns from the current rule set and provided common facts to improve initial query performance.